# s2-py

A setuptools wrapper around the [s2geometry library](https://github.com/google/s2geometry).

### Requirements
The libs from s2geometry are still required. See [here](https://github.com/google/s2geometry/master/README.md)

Note that currently it seems that the Google test framework is [mistakenly not optional](https://github.com/google/s2geometry/issues/67).

### Notes
All credit goes to Google; this is just a wrapper around their lib.